@@ -12,14 +12,18 @@ from typing import (
     Type,
     TypeVar,
     Union,
+    overload,
 )
 
 from cached_property import cached_property  # type: ignore
+from typing_extensions import Literal
 
 from strawberry.annotation import StrawberryAnnotation
 from strawberry.arguments import UNSET, StrawberryArgument
+from strawberry.exceptions import InvalidFieldArgument
 from strawberry.type import StrawberryType
 from strawberry.types.info import Info
+from strawberry.union import StrawberryUnion
 from strawberry.utils.mixins import GraphQLNameMixin
 
 from .permission import BasePermission
@@ -102,6 +106,23 @@ class StrawberryField(dataclasses.Field, GraphQLNameMixin):
         if not isinstance(resolver, StrawberryResolver):
             resolver = StrawberryResolver(resolver)
 
+        for argument in resolver.arguments:
+            if isinstance(argument.type_annotation.annotation, str):
+                continue
+            elif isinstance(argument.type, StrawberryUnion):
+                raise InvalidFieldArgument(
+                    self.python_name,
+                    argument.python_name,
+                    "Union",
+                )
+            elif getattr(argument.type, "_type_definition", False):
+                if argument.type._type_definition.is_interface:
+                    raise InvalidFieldArgument(
+                        self.python_name,
+                        argument.python_name,
+                        "Interface",
+                    )
+
         self.base_resolver = resolver
 
         return self
@@ -267,8 +288,45 @@ class StrawberryField(dataclasses.Field, GraphQLNameMixin):
         return self._has_async_permission_classes or self._has_async_base_resolver
 
 
+T = TypeVar("T")
+
+
+@overload
 def field(
-    resolver: Optional[_RESOLVER_TYPE] = None,
+    *,
+    resolver: Callable[[], T],
+    name: Optional[str] = None,
+    is_subscription: bool = False,
+    description: Optional[str] = None,
+    init: Literal[False] = False,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    federation: Optional[FederationFieldParams] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
+) -> T:
+    ...
+
+
+@overload
+def field(
+    *,
+    name: Optional[str] = None,
+    is_subscription: bool = False,
+    description: Optional[str] = None,
+    init: Literal[True] = True,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    federation: Optional[FederationFieldParams] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
+) -> Any:
+    ...
+
+
+@overload
+def field(
+    resolver: _RESOLVER_TYPE,
     *,
     name: Optional[str] = None,
     is_subscription: bool = False,
@@ -279,6 +337,25 @@ def field(
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
 ) -> StrawberryField:
+    ...
+
+
+def field(
+    resolver=None,
+    *,
+    name=None,
+    is_subscription=False,
+    description=None,
+    permission_classes=None,
+    federation=None,
+    deprecation_reason=None,
+    default=UNSET,
+    default_factory=UNSET,
+    # This init parameter is used by PyRight to determine whether this field
+    # is added in the constructor or not. It is not used to change
+    # any behavior at the moment.
+    init=None,
+) -> Any:
     """Annotates a method or property as a GraphQL field.
 
     This is normally used inside a type declaration:
@@ -308,6 +385,7 @@ def field(
     )
 
     if resolver:
+        assert init is not True, "Can't set init as True when passing a resolver."
         return field_(resolver)
     return field_
 
